GraphQL queries in the terminal
===============================

Add gif here!

Ideas
-----

- Save latest query and cursor position.
- Print built query.
- Contols:
  - Execute built query when pressing <Enter>.
  - Toggle checkbox with <Space>.
  - Use arrows ro navigate.
  - Use '/' to fuzzy find field.
- Query is all selected visible leaves.
- Variables?
